@@ -1,6 +1,7 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) 2013  Adrien Devresse <adrien.devresse@cern.ch>, CERN
+ * Copyright (C) CERN 2013
+ * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -38,7 +39,7 @@ int davixRequestToFileStatus(HttpRequest* req, const std::string & scope, DavixE
     int ret = 0;
     if( httpcodeIsValid(reqcode) == false){
         DavixError* tmp_err=NULL;
-        httpcodeToDavixCode(reqcode, scope, "",&tmp_err);
+        httpcodeToDavixError(reqcode, scope, "",&tmp_err);
         if(tmp_err && tmp_err->getStatus() != StatusCode::OK){
             DavixError::propagateError(err, tmp_err);
             ret = -1;
@@ -50,6 +51,13 @@ int davixRequestToFileStatus(HttpRequest* req, const std::string & scope, DavixE
 }
 
 
+void check_file_status(HttpRequest & req, const std::string & scope){
+    const int code =req.getRequestCode();
+    if( httpcodeIsValid(code) == false){
+        httpcodeToDavixException(code, scope);
+    }
+}
+
 void setup_offset_request(HttpRequest* req, const dav_off_t *start_len, const dav_size_t *size_read, const dav_size_t number_ops){
    std::ostringstream buffer;
 
@@ -59,7 +67,7 @@ void setup_offset_request(HttpRequest* req, const dav_off_t *start_len, const da
         if( i > 0)
             buffer << ",";
 
-       if(size_read > 0)
+       if(size_read[i] > 0)
            buffer << start_len[i] << "-"<< (start_len[i]+size_read[i]-1);
        else
             buffer << start_len [i]<< "-";
@@ -68,52 +76,40 @@ void setup_offset_request(HttpRequest* req, const dav_off_t *start_len, const da
 
 }
 
-std::vector< std::pair<dav_size_t, std::string> > generateRangeHeadersRec(std::vector< std::pair<dav_size_t, std::string> >  & range_rec, dav_size_t max_header_size, OffsetCallback & offset_provider){
-
-    range_rec.push_back(std::pair<dav_size_t,std::string >(0, std::string()));
-    std::string & current_range = range_rec.back().second;
-    dav_size_t & current_n = range_rec.back().first;
-    current_n=0;
-    current_range.reserve(max_header_size);
-    current_range.append(offset_value);
-    dav_off_t begin, end;
-    int ret;
-    while( ( ret = offset_provider(begin, end)) >= 0){
-       std::ostringstream buffer;
-       if(current_n > 0)
-           buffer << ',';
-       buffer << begin << '-' <<  end;
-       current_range.append(buffer.str());
-       current_n++;
-       if(current_range.length() >= max_header_size)
-           return generateRangeHeadersRec(range_rec, max_header_size, offset_provider);
-    }
-    return range_rec;
-}
-
 std::vector< std::pair<dav_size_t, std::string> > generateRangeHeaders(dav_size_t max_header_size, OffsetCallback & offset_provider){
-   std::vector< std::pair<dav_size_t, std::string> > res;
-   return generateRangeHeadersRec(res, max_header_size, offset_provider);
+   std::vector< std::pair<dav_size_t, std::string> > range_rec;
+   dav_off_t begin, end;
+   int ret;
+   std::string range_string;
+   dav_size_t range_size =0;
+   std::ostringstream buffer;
+   range_string.reserve(max_header_size);
+   range_string.append(offset_value);
+
+
+   while( ( ret = offset_provider(begin, end)) >= 0){
+      buffer.str("");
+
+      /* First range? Don't add a coma */
+      if(range_string.size() != offset_value.size())
+          buffer << ",";
+      buffer << begin << '-' <<  end;
+
+      range_string.append(buffer.str());
+      range_size++;
+      if(range_string.size() >= max_header_size){
+          range_rec.push_back(std::make_pair(range_size, range_string));
+          range_size = 0;
+          range_string.assign(offset_value);
+      }
+   }
+   if(range_size > 0)
+       range_rec.push_back(std::make_pair(range_size, range_string));
+
+   return range_rec;
 }
 
-void fill_stat_from_fileproperties(struct stat* st, const  FileProperties & prop){
-    memset(st, 0, sizeof(struct stat));
-    st->st_mtime = prop.mtime;
-    st->st_atime = prop.atime;
-    st->st_ctime = prop.ctime;
-    st->st_size = prop.size;
-    st->st_mode = prop.mode;
-}
 
-StatInfo &  fill_fileinfo_from_fileproperties(const  FileProperties & prop, struct StatInfo & st){
-    memset(&st,0, sizeof(struct StatInfo));
-    st.mtime =prop.mtime;
-    st.atime = prop.atime;
-    st.ctime = prop.ctime;
-    st.size = static_cast<dav_size_t>(prop.size);
-    st.mode = prop.mode;
-    return st;
-}
 
 
 
